@@ -12,7 +12,10 @@ private_IP_alias_eth_def="100"
 USAGE() {
     echo "To start, restart or stop DRBL service in DRBL Live environment."
     echo "Usage:"
-    echo "$0 {start|stop|restart}"
+    echo "$0 [OPTION] {start|stop|restart}"
+    echo "OPTION:"
+    echo "-p, --prepare-ocsroot         Prepare clonezilla image home dir also."
+    echo "-s, --skip-pause-in-the-end   Skip showing the messsage and pause in the end of execuation."
     echo "start   Start DRBL services now"
     echo "stop    Stop DRBL services now"
     echo "restart Restart DRBL services now"
@@ -89,8 +92,16 @@ config_network(){
     exit 1
   elif [ "$IP_no" -eq 1 ]; then
     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-    echo -n $msg_only_one_IP_so_create_alias_IP
+    echo "$msg_one_NIC_one_IP_limitation_prompt"
+    echo "$msg_if_lease_IP_add_to_pxe_etherboot_only"
     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+    echo -n "[Y/n] "
+    read limit_pxeclient_ans
+    case "$limit_pxeclient_ans" in
+       n|N|[nN][oO]) limit_pxeclient="no" ;;
+       *) limit_pxeclient="yes" ;;
+    esac
+    echo -n "$msg_only_one_IP_so_create_alias_IP "
     alias_done="no"
     i="$private_IP_alias_eth_def"
     while [ "$alias_done" = "no" ]; do
@@ -125,15 +136,34 @@ NET_END
 check_if_root
 
 #
-ask_and_load_lang_set en
+ask_and_load_lang_set
+
+# Default settings.
+prepare_ocsroot="no"
+pause_in_the_end="yes"
 #
-if [ $# -ne 1 ]; then
+while [ $# -gt 0 ]; do
+  case "$1" in
+    -p|--prepare-ocsroot)
+            prepare_ocsroot="yes"
+            shift ;;
+    -s|--skip-pause-in-the-end)
+            pause_in_the_end="no"
+            shift ;;
+    -*)     echo "${0}: ${1}: invalid option" >&2
+            USAGE >& 2
+            exit 2 ;;
+    *)      break ;;
+  esac
+done
+
+switch=$1
+#
+if [ -z "$switch" ]; then
   USAGE
   exit 1
 fi
 
-switch=$1
-
 #
 if ! is_boot_from_live; then
   [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
@@ -148,6 +178,12 @@ case "$switch" in
      # config network first:
      config_network
 
+     #
+     if  [ "$prepare_ocsroot" = "yes" ]; then
+        echo "Preparing clonezilla image home dir..."
+	prep-ocsroot
+     fi
+
      #
      echo "$msg_delimiter_star_line"
      echo $msg_now_continue_to_run_drblpush
@@ -162,9 +198,14 @@ case "$switch" in
      yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi -p $client_no_per_NIC
 
      echo "$msg_delimiter_star_line"
-     # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
-     echo "Modifying dhcpd.conf, now only PXE/Etherboot/DRBL client can lease IP address..."
-     perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1 $2/g' /etc/dhcp3/dhcpd.conf
+     if [ "$limit_pxeclient" = "yes" ]; then
+       # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
+       echo "Modifying dhcpd.conf, now only PXE/Etherboot/DRBL client can lease IP address from this server..."
+       perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1$2/g' /etc/dhcp3/dhcpd.conf
+     else
+       echo "Modifying dhcpd.conf, now ANY client, not only PXE/Etherboot/DRBL client, can lease IP address from this server..."
+       perl -pi -e 's/^([[:space:]]*)#*[[:space:]]*(allow members of "DRBL-Client";)/$1#$2/g' /etc/dhcp3/dhcpd.conf
+     fi
 
      echo "$msg_delimiter_star_line"
      echo "Enable auto login for drbl clients..."
@@ -178,7 +219,7 @@ case "$switch" in
          passwd_autologin="$passwd_autologin_def"
          ;;
      esac
-     drbl-login-switch -a -p "${passwd_autologin}"
+     drbl-login-switch -a --no_nis_update -p "${passwd_autologin}"
 
      echo "$msg_delimiter_star_line"
      # turn on tcpwrapper
@@ -210,23 +251,26 @@ case "$switch" in
      #
      echo "$msg_delimiter_star_line"
      echo "$msg_done!"
-     [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-     echo "$msg_all_set_you_can_turn_on_clients"
-     [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-     echo -n $msg_press_enter_to_continue
-     # This is a weird problem about tftpd-hpa when it is restared in 'drbl-all-service start' in the above. It's:
-     # -------
-     # /etc/init.d/tftpd-hpa restart
-     # echo -n "press key... "
-     # read
-     # -------
-     # and we always get such an error when running it:
-     # -------
-     # Restarting HPA's tftpd: in.tftpd.
-     # press key... ./td: line 4: read: read error: 0: Resource temporarily unavailable
-     # -------
-     # Therefore we use < /dev/stdin to avoid tihs.
-     read dummy_var < /dev/stdin
+
+     if  [ "$pause_in_the_end" = "yes" ]; then
+       [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+       echo "$msg_all_set_you_can_turn_on_clients"
+       [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+       echo -n $msg_press_enter_to_continue
+       # This is a weird problem about tftpd-hpa when it is restared in 'drbl-all-service start' in the above. It's:
+       # -------
+       # /etc/init.d/tftpd-hpa restart
+       # echo -n "press key... "
+       # read
+       # -------
+       # and we always get such an error when running it:
+       # -------
+       # Restarting HPA's tftpd: in.tftpd.
+       # press key... ./td: line 4: read: read error: 0: Resource temporarily unavailable
+       # -------
+       # Therefore we use < /dev/stdin to avoid tihs.
+       read dummy_var < /dev/stdin
+     fi
      ;;
    "stop")
      # block all the clients.
